# Configuration for a Puppet client.  Handles the Puppet configuration and
# syslog filtering rules.

# replace: set to false if you don't want Puppet to overwrite an existing
#   /etc/puppet/puppet.conf.
#
# Helper define to generate Puppet configuration files.
define base::puppetclient::config(
  $ensure,
  $template    = 'base/puppetclient/puppet.conf.template.erb',
  $runinterval = '',
  $server      = '',
  $ca_server   = '',
  $in_noop     = false,
  $pm          = false,
  $start       = true,
  $replace     = true,
  $defaultfile = '/etc/default/puppet',
  $is_master   = false,
  $diff_args   = '-u'
) {

  $ssldir = $::osfamily ? {
    'Debian' => '/etc/puppet/ssl',
    'RedHat' => '/var/lib/puppet/ssl',
  }

  case $ensure {
    present: {
      if ($is_master) {

        # The Puppet config file
        $puppet_config = '/etc/puppet/puppet.conf'

        if ($::hostname =~ /jimhenson|frankoz/) {
          # CASE 1. Puppet 2.x

          # The file /etc/puppet/puppet.conf is constructed by first writing
          # the ERB template file templates/puppet.conf.template.erb into
          # /etc/puppet/puppet.conf.template.
          #
          # We then convert /etc/puppet/puppet.conf.template into
          # /etc/puppet/puppet.conf using generate_conf.
          #
          # Note that for generate-conf to work we must have the database ini
          # file in place.

          # Puppet masters need the database credentials file, so download
          # the wallet object.
          include base::puppetclient::db_credentials

          $template_file = '/etc/puppet/puppet.conf.template'
          $db_config     = $puppetclient::db_credentials::puppet_db_ini_file

          # 1. Install the template file.
          file { $template_file:
            content => template('base/puppetclient/puppet.conf.template.erb'),
            mode    => '0644',
            owner   => 'root',
            group   => 'root',
          }

          # 2. Convert the template file into /etc/puppet/puppet.conf.
          exec { 'generate-conf puppet.conf':
            command     =>
              "generate-conf --template $template_file --config $db_config --newfile $puppet_config",
            refreshonly => true,
            subscribe   =>
              [
                File[$template_file],
                Base::Wallet[$puppetclient::db_credentials::credentials_wallet_name],
              ]
          }
        } else {
          # CASE 2. Puppet 3.x

          file { $puppet_config:
            content => template('base/puppetclient/puppet.conf.template.erb'),
            mode    => '0644',
            owner   => 'root',
            group   => 'root',
          }
        }
      } else {
        # not $is_master
        file { $name:
          content => template($template),
          replace => $replace,
        }
      }
    }
    absent:  { file { $name: ensure => absent } }
    default: { crit "Invalid ensure value: $ensure" }
  }

  file { $defaultfile:
    content => template('base/puppetclient/puppet.default.erb'),
  }

}

